From 2878a6487e20094eba0e2ec362c818f9e4e85a6b Mon Sep 17 00:00:00 2001
From: zzz <zzz@mail.i2p>
Date: Thu, 7 Aug 2014 17:05:25 +0000
Subject: [PATCH] KeysAndCert: Change hashcode to prevent possible collisions
 caused by apps with zeroed pubkey

---
 core/java/src/net/i2p/data/KeysAndCert.java | 10 ++++++----
 1 file changed, 6 insertions(+), 4 deletions(-)

diff --git a/core/java/src/net/i2p/data/KeysAndCert.java b/core/java/src/net/i2p/data/KeysAndCert.java
index 6936c0f3e4..b0a8a845b7 100644
--- a/core/java/src/net/i2p/data/KeysAndCert.java
+++ b/core/java/src/net/i2p/data/KeysAndCert.java
@@ -130,17 +130,19 @@ public class KeysAndCert extends DataStructureImpl {
                && DataHelper.eq(_certificate, ident._certificate);
     }
     
     /** the public key has enough randomness in it to use it by itself for speed */
     @Override
     public int hashCode() {
-        if (_publicKey == null)
+        // don't use public key, some app devs thinking of using
+        // an all-zeros or leading-zeros public key for destinations
+        if (_signingKey == null)
             return 0;
-        return _publicKey.hashCode();
+        return _signingKey.hashCode();
     }
     
     @Override
     public String toString() {
-        StringBuilder buf = new StringBuilder(64);
+        StringBuilder buf = new StringBuilder(256);
         buf.append('[').append(getClass().getSimpleName()).append(": ");
         buf.append("\n\tHash: ").append(getHash().toBase64());
         buf.append("\n\tCertificate: ").append(_certificate);
@@ -130,17 +130,19 @@ public class KeysAndCert extends DataStructureImpl {
     }
     
-    /** the public key has enough randomness in it to use it by itself for speed */
+    /** the signing key has enough randomness in it to use it by itself for speed */
     @Override
     public int hashCode() {
-- 
GitLab